@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: chord.cpp 4464 2011-07-03 15:45:09Z lasconic $
+//  $Id: chord.cpp 4902 2011-10-26 18:01:51Z wschweer $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -499,7 +499,7 @@ QRectF Chord::bbox() const
 ///   \arg line       vertical position of line
 //---------------------------------------------------------
 
-void Chord::addLedgerLine(double x, int staffIdx, int line, int lr)
+void Chord::addLedgerLine(double x, int staffIdx, int line, int lr, bool visible)
       {
       double _spatium = spatium();
       double hw       = upNote()->headWidth();
@@ -509,7 +509,9 @@ void Chord::addLedgerLine(double x, int staffIdx, int line, int lr)
 
       LedgerLine* h   = new LedgerLine(score());
       h->setTrack(staffIdx * VOICES);
-      h->setVisible(!staff()->invisible());
+      if (staff()->invisible())
+            visible = false;
+      h->setVisible(visible);
 
       // ledger lines extend less than half a space on each side
 	 	  // of the notehead:
@@ -554,18 +556,26 @@ void Chord::addLedgerLines(double x, int move)
       int uppos = 1000;
       int ulr   = 0;
       int idx   = staffIdx() + move;
+      // make ledger lines invisible if all notes are invisible
+      bool visible = false;
+      foreach(const Note* note, _notes) {
+      if (note->visible()) {
+            visible = true;
+            break;
+	 	             }
+            }
       for (int ni = _notes.size() - 1; ni >= 0; --ni) {
             const Note* note = _notes[ni];
             int l = note->line();
             if (l >= 0)
                   break;
             for (int i = (uppos+1) & ~1; i < l; i += 2)
-                  addLedgerLine(x, idx, i, ulr);
+                  addLedgerLine(x, idx, i, ulr, visible);
             ulr |= (up() ^ note->mirror()) ? 0x1 : 0x2;
             uppos = l;
             }
       for (int i = (uppos+1) & ~1; i <= -2; i += 2)
-            addLedgerLine(x, idx, i, ulr);
+            addLedgerLine(x, idx, i, ulr, visible);
 
       int downpos = -1000;
       int dlr = 0;
@@ -574,12 +584,12 @@ void Chord::addLedgerLines(double x, int move)
             if (l <= 8)
                   break;
             for (int i = downpos & ~1; i > l; i -= 2)
-                  addLedgerLine(x, idx, i, dlr);
+                  addLedgerLine(x, idx, i, dlr, visible);
             dlr |= (up() ^ note->mirror()) ? 0x1 : 0x2;
             downpos = l;
             }
       for (int i = downpos & ~1; i >= 10; i -= 2)
-            addLedgerLine(x, idx, i, dlr);
+            addLedgerLine(x, idx, i, dlr, visible);
       }
 
 //-----------------------------------------------------------------------------
@@ -731,7 +741,7 @@ void Chord::write(Xml& xml, int startTick, int endTick) const
 //   Chord::readNote
 //---------------------------------------------------------
 
-void Chord::readNote(QDomElement e, const QList<Tuplet*>& tuplets)
+void Chord::readNote(QDomElement e, QList<Tuplet*>& tuplets, Measure* measure)
       {
       Note* note = new Note(score());
       int ptch   = e.attribute("pitch", "-1").toInt();
@@ -781,7 +791,7 @@ void Chord::readNote(QDomElement e, const QList<Tuplet*>& tuplets)
                   }
             else if (tag == "move")
                   setStaffMove(i);
-            else if (!ChordRest::readProperties(e, tuplets))
+            else if (!ChordRest::readProperties(e, tuplets, measure))
                   domError(e);
             }
       if (ptch != -1) {
@@ -800,7 +810,7 @@ void Chord::readNote(QDomElement e, const QList<Tuplet*>& tuplets)
 void Chord::read(QDomElement e)
       {
       QList<Tuplet*> tl;
-      read(e, tl);
+      read(e, tl, 0);
       if (!duration().isValid())
             convertTicks();
       }
@@ -809,7 +819,7 @@ void Chord::read(QDomElement e)
 //   Chord::read
 //---------------------------------------------------------
 
-void Chord::read(QDomElement e, const QList<Tuplet*>& tuplets)
+void Chord::read(QDomElement e, QList<Tuplet*>& tuplets, Measure* measure)
       {
       for (e = e.firstChildElement(); !e.isNull(); e = e.nextSiblingElement()) {
             QString tag(e.tagName());
@@ -869,7 +879,7 @@ void Chord::read(QDomElement e, const QList<Tuplet*>& tuplets)
                   _stem->read(e);
                   add(_stem);
                   }
-            else if (!ChordRest::readProperties(e, tuplets))
+            else if (!ChordRest::readProperties(e, tuplets, measure))
                   domError(e);
             }
       if (!duration().isValid())
@@ -1133,7 +1143,7 @@ void Chord::layoutStem()
                   if (up()) {
                         double dy  = dl + downnote->stemYoff(true);
                         double sel = ul - normalStemLen;
-      
+
                         if (shortenStem && (sel < 0.0) && (hookIdx == 0 || !downnote->mirror()))
                               sel -= sel  * progression.val();
                         if (sel > 2.0)
@@ -1145,7 +1155,7 @@ void Chord::layoutStem()
                   else {
                         double uy  = ul + upnote->stemYoff(false);
                         double sel = dl + normalStemLen;
-      
+
                         if (shortenStem && (sel > 4.0) && (hookIdx == 0 || downnote->mirror()))
                               sel -= (sel - 4.0)  * progression.val();
                         if (sel < 2.0)
@@ -1155,7 +1165,7 @@ void Chord::layoutStem()
                               stemLen = shortest;
                         }
                   }
-                  
+
 
             QPointF npos(stemPos(_up, false));
 
@@ -1315,7 +1325,7 @@ void Chord::layout()
             if (accidental){
                   x = (accidental->x() + accidental->bbox().x()) * mag()+ note->x();
                   }
-            
+
             if (x < lx)
                   lx = x;
             }
