@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: excerpt.cpp 3969 2011-02-01 17:49:25Z lasconic $
+//  $Id: excerpt.cpp 5400 2012-03-01 16:30:43Z lasconic $
 //
 //  Copyright (C) 2009 Werner Schweer and others
 //
@@ -232,11 +232,15 @@ void Score::writeExcerpt(Excerpt* excerpt, Xml& xml)
                   }
             else {
                   if (el->track() != -1) {
-//                        if (el->type() != VOLTA) {                      // HACK
+                        if (el->type() != VOLTA) {                      // HACK
                               if (trackOffset[staffIdx] == HIDDEN)
                                     continue;
                               xml.trackDiff = trackOffset[staffIdx];
-//                              }
+                              }
+                        else {
+                              if (el->track() == 0)
+                                    xml.trackDiff = staffIdx;
+                              }
                         }
                   }
             el->write(xml);
