@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: menus.cpp 4434 2011-06-28 09:51:39Z lasconic $
+//  $Id: menus.cpp 5464 2012-03-12 23:40:24Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -58,6 +58,7 @@
 #include "drumset.h"
 #include "spacer.h"
 #include "measure.h"
+#include "preferences.h"
 
 extern bool useFactorySettings;
 
@@ -74,8 +75,14 @@ void MuseScore::showPalette(bool visible)
             connect(paletteBox, SIGNAL(paletteVisible(bool)), a, SLOT(setChecked(bool)));
             addDockWidget(Qt::LeftDockWidgetArea, paletteBox);
 
+            QFile f(dataPath + "/" + "mscore-palette.xml");
+            if(preferences.firstStart12) {//delete palette file on very first startup with 1.2
+                  f.remove();
+                  preferences.firstStart12 = false;
+                  preferences.dirty  = true;      
+                  }
+            
             if (!useFactorySettings) {
-                  QFile f(dataPath + "/" + "mscore-palette.xml");
                   if (f.exists()) {
                         if (paletteBox->read(&f)) {
                               paletteBox->setShown(visible);
@@ -239,19 +246,25 @@ void MuseScore::showPalette(bool visible)
             sp->setMag(.8);
             sp->setGrid(84, 23);
 
+            double l = gscore->spatium() * 7;
+
             Slur* slur = new Slur(gscore);
+            slur->setLen(l);
             slur->setId(0);
             sp->append(slur, tr("Slur"));
 
-            Hairpin* gabel0 = new Hairpin(gscore);
-            gabel0->setSubtype(0);
-            sp->append(gabel0, tr("Crescendo"));
+            Hairpin* hairpin0 = new Hairpin(gscore);
+            hairpin0->setLen(l);
+            hairpin0->setSubtype(0);
+            sp->append(hairpin0, tr("Crescendo"));
 
-            Hairpin* gabel1 = new Hairpin(gscore);
-            gabel1->setSubtype(1);
-            sp->append(gabel1, tr("Diminuendo"));
+            Hairpin* hairpin1 = new Hairpin(gscore);
+            hairpin1->setLen(l);
+            hairpin1->setSubtype(1);
+            sp->append(hairpin1, tr("Diminuendo"));
 
             Volta* volta = new Volta(gscore);
+            volta->setLen(l);
             volta->setSubtype(Volta::VOLTA_CLOSED);
             volta->setText("1.");
             QList<int> il;
@@ -260,6 +273,7 @@ void MuseScore::showPalette(bool visible)
             sp->append(volta, tr("Prima volta"));
 
             volta = new Volta(gscore);
+            volta->setLen(l);
             volta->setSubtype(Volta::VOLTA_CLOSED);
             volta->setText("2.");
             il.clear();
@@ -268,6 +282,7 @@ void MuseScore::showPalette(bool visible)
             sp->append(volta, tr("Seconda volta"));
 
             volta = new Volta(gscore);
+            volta->setLen(l);
             volta->setSubtype(Volta::VOLTA_CLOSED);
             volta->setText("3.");
             il.clear();
@@ -276,6 +291,7 @@ void MuseScore::showPalette(bool visible)
             sp->append(volta, tr("Terza volta"));
 
             volta = new Volta(gscore);
+            volta->setLen(l);
             volta->setSubtype(Volta::VOLTA_OPEN);
             volta->setText("2.");
             il.clear();
@@ -284,34 +300,42 @@ void MuseScore::showPalette(bool visible)
             sp->append(volta, tr("Seconda volta 2"));
 
             Ottava* ottava = new Ottava(gscore);
+            ottava->setLen(l);
             ottava->setSubtype(0);
             sp->append(ottava, tr("8va"));
 
             ottava = new Ottava(gscore);
+            ottava->setLen(l);
             ottava->setSubtype(1);
             sp->append(ottava, tr("15ma"));
 
             ottava = new Ottava(gscore);
+            ottava->setLen(l);
             ottava->setSubtype(2);
             sp->append(ottava, tr("8vb"));
 
             ottava = new Ottava(gscore);
+            ottava->setLen(l);
             ottava->setSubtype(3);
             sp->append(ottava, tr("15mb"));
 
             Pedal* pedal = new Pedal(gscore);
+            pedal->setLen(l);
             sp->append(pedal, tr("pedal"));
 
             Trill* trill = new Trill(gscore);
+            trill->setLen(l);
             sp->append(trill, tr("Trill line"));
 
             TextLine* textLine = new TextLine(gscore);
+            textLine->setLen(l);
             textLine->setBeginText("VII");
             textLine->setEndHook(true);
             textLine->setEndHookHeight(Spatium(1.5));
             sp->append(textLine, tr("Text line"));
 
             TextLine* line = new TextLine(gscore);
+            line->setLen(l);
             line->setDiagonal(true);
             sp->append(line, tr("Line"));
 
@@ -615,10 +639,10 @@ void MuseScore::showPalette(bool visible)
             ik->setAction(getAction("no-beam"));
             sp->append(ik, tr("No beam"));
 
-            ik = new Icon(gscore);
+            /*ik = new Icon(gscore);
             ik->setSubtype(ICON_BEAM32);
             ik->setAction(getAction("beam32"));
-            sp->append(ik, tr("Start subbeam"));
+            sp->append(ik, tr("Start subbeam"));*/
 
             ik = new Icon(gscore);
             ik->setSubtype(ICON_AUTOBEAM);
