@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: rendermidi.cpp 4364 2011-06-11 16:58:51Z lasconic $
+//  $Id: rendermidi.cpp 5374 2012-02-24 18:55:11Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -142,7 +142,7 @@ Volta* Score::searchVolta(int tick) const
       }
 
 //---------------------------------------------------------
-//   collectChord
+//   collectChord, used for appogiaturra
 //---------------------------------------------------------
 
 void Score::collectChord(EventMap* events, Instrument* instr, Chord* chord, int tick, int len)
@@ -171,29 +171,24 @@ void Score::collectChord(EventMap* events, Instrument* instr, Chord* chord, int
 
 //---------------------------------------------------------
 //   collectNote
+//   onTime is the offset based on repeat
+//   len is the expected len of the chord
 //---------------------------------------------------------
 
 void Score::collectNote(EventMap* events, int channel, Note* note, int onTime, int len)
       {
-      int noteTick    = note->chord()->tick();
-      int noteOffTick = noteTick + note->chord()->tickLen();
-
-      if (note->onTimeType() == AUTO_VAL)
-            note->setOnTimeOffset(onTime - noteTick);
-      else if (note->onTimeType() == USER_VAL)
-            onTime = noteTick + note->onTimeOffset();
-      else {
-            note->setOnTimeOffset(onTime - noteTick);
-            onTime += note->onTimeUserOffset();
+      if (note->onTimeType() == USER_VAL)
+            onTime += note->onTimeOffset();
+      else if (note->onTimeType() == OFFSET_VAL) {
+            onTime += ((note->onTimeUserOffset() * note->chord()->tickLen()) / 100);
             }
+            
       int offTime = onTime + len;
-      if (note->offTimeType() == AUTO_VAL)
-            note->setOffTimeOffset(offTime - noteOffTick);
-      else if (note->offTimeType() == USER_VAL)
-            offTime = noteOffTick + note->offTimeOffset();
-      else  {
-            note->setOffTimeOffset(offTime - noteOffTick);
-            offTime += note->offTimeUserOffset();
+      if (note->offTimeType() == USER_VAL)
+            //apply offset on real length
+            offTime = onTime + note->chord()->tickLen() + note->offTimeOffset();
+      else if (note->offTimeType() == OFFSET_VAL) {
+            offTime = onTime + note->chord()->tickLen() + ((note->offTimeUserOffset() * note->chord()->tickLen()) / 100);
             }
 
       if (note->hidden() || note->tieBack())       // do not play overlapping notes
@@ -350,7 +345,7 @@ void Score::collectMeasureEvents(EventMap* events, Measure* m, int staffIdx, int
                         }
 
                   //detect 8th on the offbeat
-                  bool swing = ((tick - m->tick()+offSet)%AL::division == 240 && chord->tickLen() == 240);
+                  bool swing = ((tick - m->tick()+offSet)%AL::division == 240 && chord->tickLen() >= 240);
 
                   if (swing)
                         tick += (swingCoeff * AL::division /2);
@@ -377,7 +372,7 @@ void Score::collectMeasureEvents(EventMap* events, Measure* m, int staffIdx, int
                         bool tiedNote = false;
                         int lastNoteLen = len;
                         //swing
-                        if (swing)
+                        if (swing && chord->tickLen() == 240)
                             len *= (1-swingCoeff);
                         if (swingBeat)
                             len *= (1+swingCoeff);
@@ -500,7 +495,7 @@ void Score::toEList(EventMap* events, int staffIdx)
                               ev->setChannel(channel);
                               ev->setController(CTRL_SUSTAIN);
                               ev->setValue(0);
-                              events->insertMulti(p->tick2() + tickOffset, ev);
+                              events->insertMulti(p->tick2() + tickOffset - 1, ev);
                               }
                         }
                   }
@@ -556,7 +551,13 @@ void Score::toEList(EventMap* events)
 void Score::fixPpitch()
       {
       int ns = nstaves();
+      
+//ugly but clang cannot deal with 2/ while gcc4.6 can cope with 1/
+#ifdef Q_WS_MAC
+      QList<OttavaShiftSegment>* osl = new QList<OttavaShiftSegment>[ns];
+#else
       QList<OttavaShiftSegment> osl[ns];
+#endif
 
       //
       //    collect ottavas
@@ -574,8 +575,13 @@ void Score::fixPpitch()
       //
       //    collect Dynamics
       //
+//ugly but clang cannot deal with 2/ while gcc4.6 can cope with 1/
+#ifdef Q_WS_MAC
+      VeloList *velo = new VeloList[ns];
+#else
       VeloList velo[ns];
-
+#endif
+      
       for (int staffIdx = 0; staffIdx < nstaves(); ++staffIdx) {
             velo[staffIdx].setVelo(0, 80);
             Part* prt      = part(staffIdx);
@@ -669,6 +675,10 @@ void Score::fixPpitch()
                         }
                   }
             }
+#ifdef Q_WS_MAC      
+      delete velo;
+      delete osl;
+#endif
       }
 
 
