@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: score.cpp 4136 2011-03-30 19:54:49Z lasconic $
+//  $Id: score.cpp 5407 2012-03-03 14:17:18Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -354,7 +354,7 @@ bool Score::read(QString name)
 
       QString cs = info.suffix();
       QString csl = cs.toLower();
-      
+
       if (csl == "mscz") {
             if (!loadCompressedMsc(name))
                   return false;
@@ -375,12 +375,10 @@ bool Score::read(QString name)
             if (csl == "xml") {
                   if (!importMusicXml(name))
                         return false;
-                  connectSlurs();
                   }
             else if (csl == "mxl") {
                   if (!importCompressedMusicXml(name))
                         return false;
-                  connectSlurs();
                   }
             else if (csl == "mid" || csl == "midi" || csl == "kar") {
                   if (!importMidi(name))
@@ -413,6 +411,11 @@ bool Score::read(QString name)
                   }
             else {
                   printf("unknown file suffix <%s>, name <%s>\n", qPrintable(cs), qPrintable(name));
+                  if(!noGui) {
+                        QMessageBox::critical(0, "MuseScore",
+                           tr("Can't open file. File extension \"%1\" not supported.").arg(cs)
+                           );
+                        }
                   return false;
                   }
             }
@@ -2126,7 +2129,7 @@ printf("Score::addCustomKeySig idx %d\n", idx);
 
 KeySig* Score::customKeySig(int idx) const
       {
-      return customKeysigs[idx];
+      return customKeysigs.value(idx);
       }
 
 //---------------------------------------------------------
@@ -2135,11 +2138,17 @@ KeySig* Score::customKeySig(int idx) const
 
 KeySig* Score::keySigFactory(KeySigEvent e)
       {
-      KeySig* ks;
+      KeySig* ks = 0;
       if (!e.isValid())
             return 0;
       if (e.custom()) {
-            ks = new KeySig(*customKeysigs[e.customType()]);
+            KeySig* cks = customKeysigs.value(e.customType());
+            if (cks)
+                  ks = new KeySig(*cks);
+           else {
+                  qDebug("Score::keySigFactory: invalid custom key index");
+                  return 0;
+                  }
             }
       else {
             ks = new KeySig(this);
