@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: seq.cpp 4157 2011-04-11 08:48:48Z lasconic $
+//  $Id: seq.cpp 5405 2012-03-03 12:35:29Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -165,20 +165,6 @@ bool Seq::init()
       bool useAlsaFlag      = preferences.useAlsaAudio;
       bool usePortaudioFlag = preferences.usePortaudioAudio;
 
-#ifdef USE_JACK
-      if (useJackFlag) {
-            useAlsaFlag      = false;
-            usePortaudioFlag = false;
-            driver = new JackAudio(this);
-            if (!driver->init()) {
-                  printf("no JACK server found\n");
-                  delete driver;
-                  driver = 0;
-                  }
-            else
-                  useJACK = true;
-            }
-#endif
 #ifdef USE_ALSA
       if (driver == 0 && useAlsaFlag) {
             driver = new AlsaAudio(this);
@@ -193,7 +179,7 @@ bool Seq::init()
             }
 #endif
 #ifdef USE_PORTAUDIO
-      if (usePortaudioFlag) {
+      if (driver == 0 && usePortaudioFlag) {
             driver = new Portaudio(this);
             if (!driver->init()) {
                   printf("no audio output found\n");
@@ -204,6 +190,21 @@ bool Seq::init()
                   usePortaudio = true;
             }
 #endif
+#ifdef USE_JACK
+      if (driver == 0 && useJackFlag) {
+            useAlsaFlag      = false;
+            usePortaudioFlag = false;
+            driver = new JackAudio(this);
+            if (!driver->init()) {
+                  printf("no JACK server found\n");
+                  delete driver;
+                  driver = 0;
+                  }
+            else
+                  useJACK = true;
+            }
+#endif
+
       if (driver == 0) {
 #if 0
             QString s = tr("Init audio driver failed.\n"
