@@ -27,6 +27,7 @@
 #include "preferences.h"
 #include "sym.h"
 #include "text.h"
+#include "mscore.h"
 
 //---------------------------------------------------------
 //   TextLineSegment
@@ -268,8 +269,6 @@ TextLine::TextLine(Score* s)
       _beginSymbol       = -1;
       _continueSymbol    = -1;
       _endSymbol         = -1;
-
-      setLen(spatium() * 7);   // for use in palettes
       }
 
 TextLine::TextLine(const TextLine& e)
@@ -422,11 +421,11 @@ bool TextLine::readProperties(QDomElement e)
       else if (tag == "hookUp")           // obsolete
             _endHookHeight *= -1.0;
       else if (tag == "beginSymbol" || tag == "symbol")     // "symbol" is obsolete
-            _beginSymbol = text.toInt();
+            _beginSymbol = resolveSymCompatibility(text.toInt());
       else if (tag == "continueSymbol")
-            _continueSymbol = text.toInt();
+            _continueSymbol = resolveSymCompatibility(text.toInt());
       else if (tag == "endSymbol")
-            _endSymbol = text.toInt();
+            _endSymbol = resolveSymCompatibility(text.toInt());
       else if (tag == "beginSymbolOffset")
             _beginSymbolOffset = readPoint(e);
       else if (tag == "continueSymbolOffset")
@@ -464,6 +463,23 @@ bool TextLine::readProperties(QDomElement e)
       return true;
       }
 
+int TextLine::resolveSymCompatibility(int i)
+      {
+      if(score()->programVersion() < 10100 && score()->programVersion() != 0) {
+            //ugly fix : be sure we are not dragging a line, if yes don't resolve compatibility
+            bool resolve = false;
+            ScoreView* scoreView = mscore->currentScoreView();
+            if(scoreView)
+                  resolve = (scoreView->getDragElement() != this);
+            else
+                  resolve = true;
+            
+            if (resolve)
+                  return i + 5;
+            }
+      return i;  
+      }
+
 //---------------------------------------------------------
 //   createLineSegment
 //---------------------------------------------------------
