@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: transposedialog.cpp 4287 2011-05-16 21:37:18Z lasconic $
+//  $Id: transposedialog.cpp 4689 2011-08-15 08:22:04Z lasconic $
 //
 //  Copyright (C) 2008-2010 Werner Schweer and others
 //
@@ -149,7 +149,7 @@ void Score::transpose()
       {
       if (last() == 0)     // empty score?
             return;
-      if (selection().state() == SEL_NONE) {
+      if (selection().state() != SEL_RANGE) {
             QMessageBox::StandardButton sb = QMessageBox::question(mscore,
                tr("MuseScore: transpose"),
                tr("There is nothing selected. Transpose whole score?"),
